@@ -14,7 +14,7 @@ cwd = str(cwd)
 
 __all__ = ["Bot"]
 
-__version__ = "0.0.8"
+__version__ = "0.0.9"
 
 class BaseBot(commands.Bot):
 	def __init__(self, *args, **kwargs):
@@ -26,7 +26,7 @@ class Bot(BaseBot):
 	"""
 	def __init__(self, *args, **kwargs):
 		super().__init__(*args, **kwargs)
-		self.cog_list = [f"cogs.{cog[:-3]}" for cog in os.listdir(cwd + "/cogs")] + ["jishaku"]
+		self.cog_list = ["cogs.fun", "cogs.misc", "jishaku"]
 	
 	async def on_ready(self):
 		for ext in self.cog_list:
